# Chopper
CHOPPER_PORT = 50051
FRAME_TIME_INTERVAL = 2
'''Number of frames to wait before capturing the next frame. Increasing this value will increase performance as less frames will be saved and thus processed later down the line.'''
# Redis
REDIS_PORT = 6379
REDIS_HOST = "10.108.148.45"
# Minio
MINIO_HOST = "minio-proj.minio-ns.svc.cluster.local:9000"
MINIO_USER = "rootuser"
MINIO_PASSWORD = "rootpass123"




import hashlib
# Generated from chatgpt
# Generates hash based on first n chunks. If n < 0 then do the whole file
def generate_fingerprint(file_path, n):
    hasher = hashlib.sha256()
    with open(file_path, 'rb') as file:
        if n > 0:
            for i in range(n):
                chunk = file.read(4096)  # Read file in chunks
                if not chunk:
                    break
                hasher.update(chunk)
        else:
            while True:
                chunk = file.read(4096)  # Read file in chunks
                if not chunk:
                    break
                hasher.update(chunk)
    return hasher.hexdigest()